@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: error.c 667 2004-05-03 11:45:01Z tijl $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +19,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "gettext.h"
+#include "intl.h"
 #include "export.h"
 
 #include "file_err.h"
@@ -49,17 +46,21 @@ TIEXPORT int TICALL tifiles_get_error(int err_num, char *error_msg)
   case ERR_FILE_OPEN:
     strcpy(error_msg, _("Msg: unable to open file."));
     strcat(error_msg, "\n");
-    strcat(error_msg, _("either the file does not exist, either there is no room."));
+    strcat(error_msg,
+	   _("either the file does not exist, either there is no room."));
     break;
 
   case ERR_FILE_CLOSE:
     strcpy(error_msg, _("Msg: unable to close file."));
     strcat(error_msg, "\n");
-    strcat(error_msg, _("Cause: either the file does not exist, either there is no room."));
+    strcat(error_msg,
+	   _
+	   ("Cause: either the file does not exist, either there is no room."));
     break;
 
   case ERR_GROUP_SIZE:
-    strcpy(error_msg, _("Msg: the size of a group file can not exceed 64KB."));
+    strcpy(error_msg,
+	   _("Msg: the size of a group file can not exceed 64KB."));
     strcat(error_msg, "\n");
     strcat(error_msg, _("Cause: too many variables/data."));
     break;
@@ -67,7 +68,9 @@ TIEXPORT int TICALL tifiles_get_error(int err_num, char *error_msg)
   case ERR_BAD_CALC:
     strcpy(error_msg, _("Msg: Unknown calculator type."));
     strcat(error_msg, "\n");
-    strcat(error_msg, _("Cause: probably due to a bug, mail to: tilp-users@lists.sf.net."));
+    strcat(error_msg,
+	   _
+	   ("Cause: probably due to a bug, mail to: tilp-users@lists.sf.net."));
     break;
 
   case ERR_INVALID_FILE:
@@ -80,11 +83,15 @@ TIEXPORT int TICALL tifiles_get_error(int err_num, char *error_msg)
   case ERR_FILE_CHECKSUM:
     strcpy(error_msg, _("Msg: checksum error."));
     strcat(error_msg, "\n");
-    strcat(error_msg, _("Cause: the file has an incorrect checksum and may be corrupted."));
+    strcat(error_msg,
+	   _
+	   ("Cause: the file has an incorrect checksum and may be corrupted."));
     break;
 
   default:
-    strcpy(error_msg, _("Error code not found in the list.\nThis is a bug. Please report it.\n."));
+    strcpy(error_msg,
+	   _
+	   ("Error code not found in the list.\nThis is a bug. Please report it.\n."));
     return err_num;
     break;
   }
