@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: file_def.h 784 2004-09-18 17:31:54Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,15 +19,13 @@
 #ifndef __TIFILES_FILEDEF__
 #define __TIFILES_FILEDEF__
 
-#define VARNAME_MAX	18	// group/name: 8 + 1 + 8 + 1
-
 #define TIFILES_NCALCS 10	// # of supported calcs
 
 typedef enum {
   CALC_NONE = 0,
   CALC_TI92P, CALC_TI92, CALC_TI89,
   CALC_TI86, CALC_TI85, CALC_TI83P, CALC_TI83, CALC_TI82, CALC_TI73,
-  CALC_V200, CALC_TI89T, CALC_TI84P,
+  CALC_V200,
 } TicalcType;
 
 typedef enum {
@@ -57,8 +52,4 @@ typedef int (*TIFILES_CHOOSE) (char *, char *);
 
 typedef int (*TIFILES_PRINTF) (const char *format, ...);
 
-// logging
-
-typedef int (*TIFILES_PRINTL) (int level, const char *format, ...);
-
 #endif
