@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: file_int.h 1396 2005-07-20 09:51:58Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format and Types library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -50,6 +47,8 @@ extern "C" {
   TIEXPORT void TICALL tifiles_set_calc(TicalcType type);
   TIEXPORT TicalcType TICALL tifiles_get_calc(void);
 
+  TIEXPORT TIFILES_PRINTF tifiles_set_printf(TIFILES_PRINTF);
+
   // for win32 (DLL partition -> memory violation)
 #ifdef __WIN32__
   TIEXPORT void *TICALL tifiles_calloc(size_t nmemb, size_t size);
@@ -111,7 +110,6 @@ extern "C" {
   TIEXPORT int TICALL tifiles_is_a_regular_file(const char *filename);
   TIEXPORT int TICALL tifiles_is_a_backup_file(const char *filename);
   TIEXPORT int TICALL tifiles_is_a_flash_file(const char *filename);
-  TIEXPORT int TICALL tifiles_is_a_tib_file(const char *filename);
 
   TIEXPORT int TICALL tifiles_which_calc_type(const char *filename);
   TIEXPORT int TICALL tifiles_which_file_type(const char *filename);
@@ -122,9 +120,9 @@ extern "C" {
   TIEXPORT const char *TICALL tifiles_calctype2signature(TicalcType calc_type);
   TIEXPORT TicalcType TICALL tifiles_signature2calctype(const char *signat);
 	
-  TIEXPORT int TICALL tifiles_folder_type(void);
-  TIEXPORT int TICALL tifiles_flash_type(void);
-  TIEXPORT int TICALL tifiles_idlist_type(void);
+  TIEXPORT const int TICALL tifiles_folder_type(void);
+  TIEXPORT const int TICALL tifiles_flash_type(void);
+  TIEXPORT const int TICALL tifiles_idlist_type(void);
   
   TIEXPORT int TICALL tifiles_is_ti8x(TicalcType calc_type);
   TIEXPORT int TICALL tifiles_is_ti9x(TicalcType calc_type);
@@ -168,16 +166,8 @@ extern "C" {
 
   // type2str.c
   TIEXPORT const char *TICALL tifiles_calctype_to_string(TicalcType type);
-  TIEXPORT TicalcType TICALL tifiles_string_to_calctype(const char *str);
-  
   TIEXPORT const char *TICALL tifiles_attribute_to_string(TifileAttr atrb);
-  TIEXPORT TifileAttr TICALL tifiles_string_to_attribute(const char *str);
-  
   TIEXPORT const char *TICALL tifiles_filetype_to_string(TifileType type);
-  TIEXPORT TifileType TICALL tifiles_string_to_filetype(const char *str);
-  
-  // printl.c
-  TIEXPORT TIFILES_PRINTL TICALL tifiles_set_printl(TIFILES_PRINTL new_printl);
 
   /************************/
   /* Deprecated functions */
