@@ -1,7 +1,5 @@
-/* $Id: files8x.c 791 2004-09-19 14:09:18Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,11 +21,6 @@
   Calcs: 73/82/83/83+/85/86
 */
 
-/*
-  Thanks to Adrian Mettler <amettler@hmc.edu> for his patch which fixes
-  some TI85/86 file issues (padded, not padded).
-*/
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -40,7 +33,6 @@
 #include "misc.h"
 #include "intelhex.h"
 #include "trans.h"
-#include "printl.h"
 
 static uint8_t fsignature[3] = { 0x1A, 0x0A, 0x00 };
 
@@ -51,7 +43,7 @@ static int is_ti8586(TicalcType calc_type)
 
 static int is_ti83p(TicalcType calc_type)
 {
-  return (calc_type == CALC_TI83P) || (calc_type == CALC_TI84P);
+  return (calc_type == CALC_TI83P);
 }
 
 /**************/
@@ -202,8 +194,6 @@ TIEXPORT int TICALL ti8x_read_regular_file(const char *filename,
   int i;
   int ti83p_flag = 0;
   uint8_t name_length = 8;	// ti85/86 only
-  uint16_t data_size;
-  uint8_t test_space;
   char signature[9];
 
   if (!tifiles_is_a_ti_file(filename))
@@ -213,7 +203,7 @@ TIEXPORT int TICALL ti8x_read_regular_file(const char *filename,
 
   f = fopen(filename, "rb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -223,45 +213,19 @@ TIEXPORT int TICALL ti8x_read_regular_file(const char *filename,
     return ERR_INVALID_FILE;
   fskip(f, 3);
   fread_n_chars(f, 42, content->comment);
-  fread_word(f, &data_size);
+  fread_word(f, NULL);
 
   // search for the number of entries by parsing the whole file
   offset = ftell(f);
   for (i = 0;; i++) {
-    int current_offset = (int)ftell(f);
-    /* We are done finding entries once we reach the end of the data segment
-     * as defined in the header.  This works better than magic numbers, as
-     * as there exist files in the wild with incorrect magic numbers that
-     * transmit correctly with TI's software and with this code.
-     *   Adrian Mettler
-     */
-    //printf("current_offset: %x, offset + data_size: %x\n",
-    //    current_offset, (uint16_t) offset + data_size);
-	  if (current_offset >= offset + data_size)
-	    break;
-
     fread_word(f, &tmp);
     if (tmp == 0x0D)
       ti83p_flag = !0;		// true TI83+ file (2 extra bytes)
-    //if ((tmp != 0x0B) && (tmp != 0x0C) && (tmp != 0x0D))
-    //break;
-    if (is_ti8586(content->calc_type)) {
-      /* name may follow one of three conventions: padded with zeroes
-       * (most correct, generated by TI's software), padded with null bytes,
-       * or unpadded.  TI's software accepts all three, so we should too.
-       */
-       fskip(f, 3);
-       fread_byte(f, &name_length);
-       fskip(f, name_length);
-       
-       fread_byte(f, &test_space);
-       fskip (f, -1);
-       
-       //printf("test_space: %x at %x\n", test_space, (int)ftell(f));
-       if (test_space == '\0' || test_space == ' ')  // skip padding if padded
-	 fskip(f, 8 - name_length);
-    }
-    else if ((content->calc_type == CALC_TI83P) || (content->calc_type == CALC_TI84P))
+    if ((tmp != 0x0B) && (tmp != 0x0C) && (tmp != 0x0D))
+      break;
+    if (is_ti8586(content->calc_type))
+      fskip(f, 12);
+    else if (content->calc_type == CALC_TI83P)
       fskip(f, 13);
     else
       fskip(f, 11);
@@ -289,14 +253,8 @@ TIEXPORT int TICALL ti8x_read_regular_file(const char *filename,
     fread_n_chars(f, name_length, entry->name);
     tixx_translate_varname(entry->name, entry->trans,
 			   entry->type, content->calc_type);
-    if (is_ti8586(content->calc_type)) {
-      /* Again, compatibility with padded and unpadded files */
-      fread_byte(f, &test_space);
-      fskip (f, -1);
-      
-      if (test_space == '\0' || test_space == ' ')  // skip padding if padded
-	fskip(f, 8 - name_length);
-    }
+    if (is_ti8586(content->calc_type))
+      fskip(f, 8 - name_length);
     if (ti83p_flag) {
       entry->attr = (fgetc(f) == 0x80 ? ATTRB_ARCHIVED : ATTRB_NONE);
       fgetc(f);
@@ -339,7 +297,7 @@ TIEXPORT int TICALL ti8x_read_backup_file(const char *filename,
 
   f = fopen(filename, "rb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -434,7 +392,7 @@ TIEXPORT int TICALL ti8x_read_flash_file(const char *filename,
   content->calc_type = tifiles_which_calc_type(filename);
   f = fopen(filename, "rb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
   file = f;
@@ -558,7 +516,7 @@ TIEXPORT int TICALL ti8x_write_regular_file(const char *fname,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     free(filename);
     return ERR_FILE_OPEN;
   }
@@ -586,7 +544,6 @@ TIEXPORT int TICALL ti8x_write_regular_file(const char *fname,
     packet_length = 0x0C;
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     packet_length = 0x0D;
     break;
   case CALC_TI82:
@@ -602,18 +559,14 @@ TIEXPORT int TICALL ti8x_write_regular_file(const char *fname,
     Ti8xVarEntry *entry = &(content->entries[i]);
 
     fwrite_word(f, packet_length);
-    fwrite_word(f, (uint16_t)entry->size);
+    fwrite_word(f, entry->size);
     fwrite_byte(f, entry->type);
-    if (is_ti8586(content->calc_type)) {
-      size_t name_length = strlen(entry->name);
-      fwrite_byte(f, (uint8_t)name_length);
-      fwrite_n_chars(f, name_length, entry->name);
-    }
-    else
-    	fwrite_n_chars(f, 8, entry->name);
+    if (is_ti8586(content->calc_type))
+      fwrite_byte(f, (uint8_t) strlen(entry->name));
+    fwrite_n_chars(f, 8, entry->name);
     if (is_ti83p(content->calc_type))
-      fwrite_word(f, (uint16_t)((entry->attr == ATTRB_ARCHIVED) ? 0x80 : 0x00));
-    fwrite_word(f, (uint16_t)entry->size);
+      fwrite_word(f, (entry->attr == ATTRB_ARCHIVED) ? 0x80 : 0x00);
+    fwrite_word(f, entry->size);
     fwrite(entry->data, entry->size, 1, f);
 
     sum += packet_length;
@@ -650,7 +603,7 @@ TIEXPORT int TICALL ti8x_write_backup_file(const char *filename,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
   // write header
@@ -736,7 +689,7 @@ TIEXPORT int TICALL ti8x_write_flash_file(const char *filename,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
   file = f;
@@ -749,7 +702,7 @@ TIEXPORT int TICALL ti8x_write_flash_file(const char *filename,
   fwrite_byte(f, content->revision_day);
   fwrite_byte(f, content->revision_month);
   fwrite_word(f, content->revision_year);
-  fwrite_byte(f, (uint8_t)strlen(content->name));
+  fwrite_byte(f, strlen(content->name));
   fwrite_8_chars(f, content->name);
   for (j = 0; j < 23; j++)
     fputc(0, f);
@@ -771,6 +724,8 @@ TIEXPORT int TICALL ti8x_write_flash_file(const char *filename,
 /* Displaying */
 /**************/
 
+#define tprintf tifiles_printf
+
 /* 
    Display the characteristics of a TI regular content
    - content [in]: the content to show
@@ -781,28 +736,28 @@ TIEXPORT int TICALL ti8x_display_regular_content(Ti8xRegular * content)
   int i;
   char trans[17];
 
-  printl3(0, "Signature:     <%s>\n",
+  tprintf("Signature:     <%s>\n",
 	  tifiles_calctype2signature(content->calc_type));
-  printl3(0, "Comment:       <%s>\n", content->comment);
-  printl3(0, "# of entries:  %i\n", content->num_entries);
+  tprintf("Comment:       <%s>\n", content->comment);
+  tprintf("# of entries:  %i\n", content->num_entries);
 
   for (i = 0; i < content->num_entries /*&& i<5 */ ; i++) {
-    printl3(0, "Entry #%i\n", i);
-    printl3(0, "  name:        <%s>\n",
+    tprintf("Entry #%i\n", i);
+    tprintf("  name:        <%s>\n",
 	    tixx_translate_varname(content->entries[i].name,
 				   trans,
 				   content->entries[i].type,
 				   content->calc_type));
-    printl3(0, "  type:        %02X (%s)\n",
+    tprintf("  type:        %02X (%s)\n",
 	    content->entries[i].type,
 	    tifiles_vartype2string(content->entries[i].type));
-    printl3(0, "  attr:        %s\n",
+    tprintf("  attr:        %s\n",
 	    tifiles_attribute_to_string(content->entries[i].attr));
-    printl3(0, "  length:      %04X (%i)\n",
+    tprintf("  length:      %04X (%i)\n",
 	    content->entries[i].size, content->entries[i].size);
   }
 
-  printl3(0, "Checksum:      %04X (%i) \n", content->checksum,
+  tprintf("Checksum:      %04X (%i) \n", content->checksum,
 	  content->checksum);
 
   return 0;
@@ -815,27 +770,27 @@ TIEXPORT int TICALL ti8x_display_regular_content(Ti8xRegular * content)
 */
 TIEXPORT int TICALL ti8x_display_backup_content(Ti8xBackup * content)
 {
-  printl3(0, "Signature:      <%s>\n",
+  tprintf("Signature:      <%s>\n",
 	  tifiles_calctype2signature(content->calc_type));
-  printl3(0, "Comment:        <%s>\n", content->comment);
-  printl3(0, "Type:           %02X (%s)\n", content->type,
+  tprintf("Comment:        <%s>\n", content->comment);
+  tprintf("Type:           %02X (%s)\n", content->type,
 	  tifiles_vartype2string(content->type));
-  printl3(0, "Mem address:    %04X (%i)\n",
+  tprintf("Mem address:    %04X (%i)\n",
 	  content->mem_address, content->mem_address);
 
-  printl3(0, "\n");
+  tprintf("\n");
 
-  printl3(0, "data_length1:   %04X (%i)\n",
+  tprintf("data_length1:   %04X (%i)\n",
 	  content->data_length1, content->data_length1);
-  printl3(0, "data_length2:   %04X (%i)\n",
+  tprintf("data_length2:   %04X (%i)\n",
 	  content->data_length2, content->data_length2);
-  printl3(0, "data_length3:   %04X (%i)\n",
+  tprintf("data_length3:   %04X (%i)\n",
 	  content->data_length3, content->data_length3);
   if (content->calc_type == CALC_TI86)
-    printl3(0, "data_length4:   %04X (%i)\n",
+    tprintf("data_length4:   %04X (%i)\n",
 	    content->data_length4, content->data_length4);
 
-  printl3(0, "Checksum:       %04X (%i) \n", content->checksum,
+  tprintf("Checksum:       %04X (%i) \n", content->checksum,
 	  content->checksum);
 
   return 0;
@@ -850,37 +805,37 @@ TIEXPORT int TICALL ti8x_display_flash_content(Ti8xFlash * content)
 {
   Ti8xFlash *ptr = content;
 
-  printl3(0, "Signature:       <%s>\n",
+  tprintf("Signature:       <%s>\n",
 	  tifiles_calctype2signature(ptr->calc_type));
-  printl3(0, "Revision:        %i.%i\n", ptr->revision_major,
+  tprintf("Revision:        %i.%i\n", ptr->revision_major,
 	  ptr->revision_minor);
-  printl3(0, "Flags:           %02X\n", ptr->flags);
-  printl3(0, "Object type:     %02X\n", ptr->object_type);
-  printl3(0, "Date:            %02X/%02X/%02X%02X\n",
+  tprintf("Flags:           %02X\n", ptr->flags);
+  tprintf("Object type:     %02X\n", ptr->object_type);
+  tprintf("Date:            %02X/%02X/%02X%02X\n",
 	  ptr->revision_day, ptr->revision_month,
 	  ptr->revision_year & 0xff, (ptr->revision_year & 0xff00) >> 8);
-  printl3(0, "Name:            <%s>\n", ptr->name);
-  printl3(0, "Device type:     %s\n",
+  tprintf("Name:            <%s>\n", ptr->name);
+  tprintf("Device type:     %s\n",
 	  ptr->device_type == DEVICE_TYPE_83P ? "ti83+" : "ti73");
-  printl3(0, "Data type:       ");
+  tprintf("Data type:       ");
   switch (ptr->data_type) {
   case 0x23:
-    printl3(0, "OS data\n");
+    tprintf("OS data\n");
     break;
   case 0x24:
-    printl3(0, "APP data\n");
+    tprintf("APP data\n");
     break;
   case 0x25:
-    printl3(0, "certificate\n");
+    tprintf("certificate\n");
     break;
   case 0x3E:
-    printl3(0, "license\n");
+    tprintf("license\n");
     break;
   default:
-    printl3(0, "Unknown (mailto roms@lpg.ticalc.org)\n");
+    tprintf("Unknown (mailto roms@lpg.ticalc.org)\n");
     break;
   }
-  printl3(0, "Number of pages: %i\n", ptr->num_pages);
+  tprintf("Number of pages: %i\n", ptr->num_pages);
 
   return 0;
 }
@@ -909,7 +864,7 @@ TIEXPORT int TICALL ti8x_display_file(const char *filename)
     ti8x_display_regular_content(&content1);
     ti8x_free_regular_content(&content1);
   } else {
-    printl3(0, "Unknwon file type !\n");
+    tprintf("Unknwon file type !\n");
     return ERR_BAD_FILE;
   }
 
