@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: files9x.c 1022 2005-05-04 16:00:01Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +34,6 @@
 #include "misc.h"
 #include "macros.h"
 #include "trans.h"
-#include "printl.h"
 
 static int fsignature[2] = { 1, 0 };
 
@@ -220,7 +216,7 @@ TIEXPORT int TICALL ti9x_read_regular_file(const char *filename,
 
   f = fopen(filename, "rb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -309,7 +305,7 @@ TIEXPORT int TICALL ti9x_read_backup_file(const char *filename,
 
   f = fopen(filename, "rb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -344,110 +340,90 @@ TIEXPORT int TICALL ti9x_read_backup_file(const char *filename,
   return 0;
 }
 
+// tib support not tested yet
 TIEXPORT int TICALL ti9x_read_flash_file(const char *filename,
 					 Ti9xFlash * head)
 {
-	FILE *f;
-	Ti9xFlash *content = head;
-	int j, tib = 0;
-	char signature[9];
+  int tib = 0;
+  FILE *f;
+  int j;
+  char buf[128];
+  Ti9xFlash *content = head;
+  char signature[9];
 
-	if (!tifiles_is_a_ti_file(filename))
-		return ERR_INVALID_FILE;
-	if (!tifiles_is_a_flash_file(filename) && !tifiles_is_a_tib_file(filename))
-		return ERR_INVALID_FILE;
+  if (!tifiles_is_a_ti_file(filename))
+    return ERR_INVALID_FILE;
+  if (!tifiles_is_a_flash_file(filename))
+    return ERR_INVALID_FILE;
 
-	// detect file type (old or new format)
-	tib = tifiles_is_a_tib_file(filename);
+  f = fopen(filename, "rb");
+  if (f == NULL) {
+    printf("Unable to open this file: <%s>\n", filename);
+    return ERR_FILE_OPEN;
+  }
 
-	f = fopen(filename, "rb");
-	if (f == NULL) 
-	{
-	    printl3(0, "Unable to open this file: <%s>\n", filename);
-		return ERR_FILE_OPEN;
-	}  
+  fread_8_chars(f, signature);
+  if (strcmp(signature, "**TIFL**"))
+    return ERR_INVALID_FILE;
 
-	if (tib) 
-	{	// tib is an old format but still in use (by developers)
-		memset(content, 0, sizeof(Ti9xFlash));
-		fseek(f, 0, SEEK_END);
-		content->data_length = (uint32_t) ftell(f);
-		fseek(f, 0, SEEK_SET);
+  // detect file type (old or new format)
+  fgets(buf, 128, f);
+  tib = (int) strstr(buf, "Advanced Mathematics Software");
+  rewind(f);
 
-		strcpy(content->name, "basecode");
-		content->data_type = 0x23;	// FLASH os
+  if (tib) {			// tib is an old format
+    fseek(f, 0, SEEK_END);
+    content->data_length = (uint32_t) ftell(f);
+    fseek(f, 0, SEEK_SET);
+    strcpy(content->name, "basecode");
+  } else {
+    long file_size;
 
-		content->data_part = (uint8_t *) calloc(content->data_length, 1);
-		if (content->data_part == NULL) 
-		{
-			fclose(f);
-			return ERR_MALLOC;
-		}
-		fread(content->data_part, content->data_length, 1, f);
-
-		switch(content->data_part[8])
-		{
-		case 1: content->device_type = DEVICE_TYPE_92P; break;	// TI92+
-		case 3: content->device_type = DEVICE_TYPE_89; break;	// TI89
-		// value added by the TI community according to HWID parameter
-		// doesn't have any 'legal existence'
-		case 8: content->device_type = DEVICE_TYPE_92P; break;	// V200PLT
-		case 9: content->device_type = DEVICE_TYPE_89; break;	// Titanium
-		}
-
-		content->next = NULL;
-	} 
-	else 
-	{
-		for (content = head;; content = content->next) 
-		{
-		    fread_8_chars(f, signature);
-		    content->calc_type = tifiles_which_calc_type(filename);
-		    fread_byte(f, &(content->revision_major));
-		    fread_byte(f, &(content->revision_minor));
-		    fread_byte(f, &(content->flags));
-		    fread_byte(f, &(content->object_type));
-		    fread_byte(f, &(content->revision_day));
-		    fread_byte(f, &(content->revision_month));
-		    fread_word(f, &(content->revision_year));
-		    fread_byte(f, NULL);
-		    fread_8_chars(f, content->name);
-		    for (j = 0; j < 23; j++)
-			fgetc(f);
-		    fread_byte(f, &(content->device_type));
-		    fread_byte(f, &(content->data_type));
-		    for (j = 0; j < 24; j++)
-			fgetc(f);
-		    fread_long(f, &(content->data_length));
-
-			content->data_part = (uint8_t *) calloc(content->data_length, 1);
-			if (content->data_part == NULL) 
-			{
-				fclose(f);
-				return ERR_MALLOC;
-			}
-			fread(content->data_part, content->data_length, 1, f);
-
-			content->next = NULL;
-
-			// check for end of file
-			fread_8_chars(f, signature);
-			if(strcmp(signature, "**TIFL**") || feof(f))
-				break;
-			fseek(f, -8, SEEK_CUR);
-
-			content->next = (Ti9xFlash *) calloc(1, sizeof(Ti9xFlash));
-			if (content->next == NULL) 
-			{
-				fclose(f);
-				return ERR_MALLOC;
-			}
-		}
-	}
+    fseek(f, 0, SEEK_END);
+    file_size = ftell(f);
+    fseek(f, 0, SEEK_SET);
 
+    for (content = head;; content = content->next) {
+      fread_8_chars(f, signature);
+      content->calc_type = tifiles_which_calc_type(filename);
+      fread_byte(f, &(content->revision_major));
+      fread_byte(f, &(content->revision_minor));
+      fread_byte(f, &(content->flags));
+      fread_byte(f, &(content->object_type));
+      fread_byte(f, &(content->revision_day));
+      fread_byte(f, &(content->revision_month));
+      fread_word(f, &(content->revision_year));
+      fread_byte(f, NULL);
+      fread_8_chars(f, content->name);
+      for (j = 0; j < 23; j++)
+	fgetc(f);
+      fread_byte(f, &(content->device_type));
+      fread_byte(f, &(content->data_type));
+      for (j = 0; j < 24; j++)
+	fgetc(f);
+      fread_long(f, &(content->data_length));
+      content->data_part = (uint8_t *) calloc(content->data_length, 1);
+      if (content->data_part == NULL) {
 	fclose(f);
+	return ERR_MALLOC;
+      }
+      fread(content->data_part, content->data_length, 1, f);
 
-	return 0;
+      content->next = NULL;
+      if (file_size == ftell(f))
+	break;
+
+      content->next = (Ti9xFlash *) calloc(1, sizeof(Ti9xFlash));
+      if (content->next == NULL) {
+	fclose(f);
+	return ERR_MALLOC;
+      }
+    }
+  }
+
+  fclose(f);
+
+  return 0;
 }
 
 /***********/
@@ -491,7 +467,7 @@ TIEXPORT int TICALL ti9x_write_regular_file(const char *fname,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     free(filename);
     return ERR_FILE_OPEN;
   }
@@ -523,7 +499,7 @@ TIEXPORT int TICALL ti9x_write_regular_file(const char *fname,
     {
       fwrite_long(f, offset);
       fwrite_8_chars(f, fentry->folder);
-      fwrite_byte(f, (uint8_t)tifiles_folder_type());
+      fwrite_byte(f, tifiles_folder_type());
       fwrite_byte(f, 0x00);
       for (j = 0; table[i][j] != -1; j++);
       fwrite_word(f, (uint16_t) j);
@@ -585,7 +561,7 @@ TIEXPORT int TICALL ti9x_write_backup_file(const char *filename,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -620,7 +596,7 @@ TIEXPORT int TICALL ti9x_write_flash_file(const char *filename,
 
   f = fopen(filename, "wb");
   if (f == NULL) {
-    printl3(0, "Unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
 
@@ -650,6 +626,8 @@ TIEXPORT int TICALL ti9x_write_flash_file(const char *filename,
 /* Displaying */
 /**************/
 
+#define tprintf tifiles_printf
+
 /* 
    Display the characteristics of a TI regular content
    - content [in]: the content to show
@@ -660,30 +638,30 @@ TIEXPORT int TICALL ti9x_display_regular_content(Ti9xRegular * content)
   int i;
   char trans[17];
 
-  printl3(0, "Signature:         <%s>\n",
+  tprintf("Signature:         <%s>\n",
 	  tifiles_calctype2signature(content->calc_type));
-  printl3(0, "Comment:           <%s>\n", content->comment);
-  printl3(0, "Default folder:    <%s>\n", content->default_folder);
-  printl3(0, "Number of entries: %i\n", content->num_entries);
+  tprintf("Comment:           <%s>\n", content->comment);
+  tprintf("Default folder:    <%s>\n", content->default_folder);
+  tprintf("Number of entries: %i\n", content->num_entries);
 
   for (i = 0; i < content->num_entries /*&& i<5 */ ; i++) {
-    printl3(0, "Entry #%i\n", i);
-    printl3(0, "  folder:    <%s>\n", content->entries[i].folder);
-    printl3(0, "  name:      <%s>\n",
+    tprintf("Entry #%i\n", i);
+    tprintf("  folder:    <%s>\n", content->entries[i].folder);
+    tprintf("  name:      <%s>\n",
 	    tixx_translate_varname(content->entries[i].name,
 				   trans,
 				   content->entries[i].type,
 				   content->calc_type));
-    printl3(0, "  type:      %02X (%s)\n",
+    tprintf("  type:      %02X (%s)\n",
 	    content->entries[i].type,
 	    tifiles_vartype2string(content->entries[i].type));
-    printl3(0, "  attr:      %s\n",
+    tprintf("  attr:      %s\n",
 	    tifiles_attribute_to_string(content->entries[i].attr));
-    printl3(0, "  length:    %04X (%i)\n",
+    tprintf("  length:    %04X (%i)\n",
 	    content->entries[i].size, content->entries[i].size);
   }
 
-  printl3(0, "Checksum:    %04X (%i) \n", content->checksum,
+  tprintf("Checksum:    %04X (%i) \n", content->checksum,
 	  content->checksum);
 
   return 0;
@@ -696,16 +674,16 @@ TIEXPORT int TICALL ti9x_display_regular_content(Ti9xRegular * content)
 */
 TIEXPORT int TICALL ti9x_display_backup_content(Ti9xBackup * content)
 {
-  printl3(0, "signature:      <%s>\n",
+  tprintf("signature:      <%s>\n",
 	  tifiles_calctype2signature(content->calc_type));
-  printl3(0, "comment:        <%s>\n", content->comment);
-  printl3(0, "ROM version:    <%s>\n", content->rom_version);
-  printl3(0, "type:           %02X (%s)\n",
+  tprintf("comment:        <%s>\n", content->comment);
+  tprintf("ROM version:    <%s>\n", content->rom_version);
+  tprintf("type:           %02X (%s)\n",
 	  content->type, tifiles_vartype2string(content->type));
-  printl3(0, "data length:    %08X (%i)\n",
+  tprintf("data length:    %08X (%i)\n",
 	  content->data_length, content->data_length);
 
-  printl3(0, "checksum:       %04X (%i) \n", content->checksum,
+  tprintf("checksum:       %04X (%i) \n", content->checksum,
 	  content->checksum);
 
   return 0;
@@ -721,39 +699,39 @@ TIEXPORT int TICALL ti9x_display_flash_content(Ti9xFlash * content)
   Ti9xFlash *ptr;
 
   for (ptr = content; ptr != NULL; ptr = ptr->next) {
-    printl3(0, "Signature:      <%s>\n",
+    tprintf("Signature:      <%s>\n",
 	    tifiles_calctype2signature(ptr->calc_type));
-    printl3(0, "Revision:       %i.%i\n",
+    tprintf("Revision:       %i.%i\n",
 	    ptr->revision_major, ptr->revision_minor);
-    printl3(0, "Flags:          %02X\n", ptr->flags);
-    printl3(0, "Object type:    %02X\n", ptr->object_type);
-    printl3(0, "Date:           %02X/%02X/%02X%02X\n",
+    tprintf("Flags:          %02X\n", ptr->flags);
+    tprintf("Object type:    %02X\n", ptr->object_type);
+    tprintf("Date:           %02X/%02X/%02X%02X\n",
 	    ptr->revision_day, ptr->revision_month,
 	    ptr->revision_year & 0xff, (ptr->revision_year & 0xff00) >> 8);
-    printl3(0, "Name:           <%s>\n", ptr->name);
-    printl3(0, "Device type:    %s\n",
+    tprintf("Name:           <%s>\n", ptr->name);
+    tprintf("Device type:    %s\n",
 	    ptr->device_type == DEVICE_TYPE_89 ? "ti89" : "ti92+");
-    printl3(0, "Data type:      ");
+    tprintf("Data type:      ");
     switch (ptr->data_type) {
     case 0x23:
-      printl3(0, "OS data\n");
+      tprintf("OS data\n");
       break;
     case 0x24:
-      printl3(0, "APP data\n");
+      tprintf("APP data\n");
       break;
     case 0x25:
-      printl3(0, "certificate\n");
+      tprintf("certificate\n");
       break;
     case 0x3E:
-      printl3(0, "license\n");
+      tprintf("license\n");
       break;
     default:
-      printl3(0, "Unknown (mailto roms@lpg.ticalc.org)\n");
+      tprintf("Unknown (mailto roms@lpg.ticalc.org)\n");
       break;
     }
-    printl3(0, "Length:         %08X (%i)\n", ptr->data_length,
+    tprintf("Length:         %08X (%i)\n", ptr->data_length,
 	    ptr->data_length);
-    printl3(0, "\n");
+    tprintf("\n");
   }
 
   return 0;
@@ -771,7 +749,7 @@ TIEXPORT int TICALL ti9x_display_file(const char *filename)
   Ti9xFlash content3;
 
   // the testing order is important: regular before backup (due to TI89/92+)
-  if (tifiles_is_a_flash_file(filename) || tifiles_is_a_tib_file(filename)) {
+  if (tifiles_is_a_flash_file(filename)) {
     ti9x_read_flash_file(filename, &content3);
     ti9x_display_flash_content(&content3);
     ti9x_free_flash_content(&content3);
@@ -784,7 +762,7 @@ TIEXPORT int TICALL ti9x_display_file(const char *filename)
     ti9x_display_backup_content(&content2);
     ti9x_free_backup_content(&content2);
   } else
-    printl3(0, "Unknwon file type !\n");
+    tprintf("Unknwon file type !\n");
 
   return 0;
 }
