@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: filesxx.h 824 2004-12-27 21:44:11Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,17 +19,13 @@
 #ifndef __TIFILES_FILESXX__
 #define __TIFILES_FILESXX__
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /* Structures (common to all calcs) */
 
 typedef struct {
 
   char folder[9];		// TI9x only
   char name[9];			// binary name
-  char trans[18];		// translated name (human readable)
+  char trans[17];		// translated name (human readable)
   uint8_t type;
   uint8_t attr;			// TI83+/89/92+ only (ATTRB_NONE or ARCHIVED)
   uint32_t size;		// uint16_t for TI8x
@@ -55,8 +48,4 @@ typedef struct {
 #include "files8x.h"
 #include "files9x.h"
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
