@@ -1,8 +1,6 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: misc.c 1130 2005-05-25 15:14:40Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,11 +26,9 @@
 #include <string.h>
 #include "stdints.h"
 #include <sys/stat.h>
-//#include "config.h"
 
 #include "export.h"
 #include "file_int.h"
-#include "printl.h"
 
 #define bswap_16(a) (a >> 8) | (a << 8)
 
@@ -49,8 +45,8 @@ TIEXPORT int TICALL hexdump(uint8_t * ptr, int len)
   int i;
 
   for (i = 0; i < len; i++)
-    printl3(0, "%02X ", ptr[i]);
-  printl3(0, "\n");
+    fprintf(stdout, "%02X ", ptr[i]);
+  fprintf(stdout, "\n");
 
   return 0;
 }
@@ -96,8 +92,9 @@ int fwrite_n_chars(FILE * f, int n, const char *s)
 
   l = strlen(s);
   if (l > n) {
-    printl3(2, "string passed in 'write_string8' is too long (>n chars).\n");
-    printl3(2, "s = <%s>, len(s) = %i\n", s, strlen(s));
+    fprintf(stderr,
+	    "libtifiles error: string passed in 'write_string8' is too long (>n chars).\n");
+    printf("s = <%s>, len(s) = %i\n", s, strlen(s));
     hexdump((uint8_t *) s, (strlen(s) < 9) ? 9 : strlen(s));
     abort();
   }
