@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: stdints.h 477 2004-04-05 08:15:06Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003-2003, Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,9 +35,9 @@
 typedef BYTE uint8_t;
 typedef WORD uint16_t;
 typedef DWORD uint32_t;
-typedef unsigned char int8_t;
-typedef unsigned short int16_t;
-typedef unsigned long int32_t;
+typedef __int8 int8_t;
+typedef __int16 int16_t;
+typedef __int32 int32_t;
 # elif defined(__BSD__)
 #  include <inttypes.h>
 # else
