@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: tifiles.h 824 2004-12-27 21:44:11Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library, a part of the TiLP project
+ *  Copyright (C) 1999-2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,17 +19,9 @@
 #ifndef __TIFILES__
 #define __TIFILES__
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #include "file_def.h"
 #include "file_int.h"
 #include "file_err.h"
 #include "file_ver.h"
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
