@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: trans.c 1396 2005-07-20 09:51:58Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,15 +26,12 @@
 */
 
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include "stdints.h"
 
-#include "gettext.h"
 #include "typesxx.h"
 #include "file_int.h"
 #include "macros.h"
-#include "printl.h"
 
 
 extern int tifiles_calc_type;
@@ -335,20 +329,18 @@ TIEXPORT uint8_t TICALL *tixx_detokenize_varname(const char *varname,
   case CALC_TI82:
   case CALC_TI83:
   case CALC_TI83P:
-  case CALC_TI84P:
-    return (uint8_t *)ti8x_detokenize_varname(varname, translate, vartype);
+    return ti8x_detokenize_varname(varname, translate, vartype);
     break;
   case CALC_TI85:
   case CALC_TI86:
   case CALC_TI89:
-  case CALC_TI89T:
   case CALC_TI92:
   case CALC_TI92P:
   case CALC_V200:
-    return (uint8_t *)strcpy(translate, varname);
+    return strcpy(translate, varname);
     break;
   default:
-    return (uint8_t *)strcpy(translate, "________");
+    return strcpy(translate, "________");
     break;
   }
 }
@@ -361,7 +353,7 @@ TIEXPORT uint8_t TICALL *tixx_detokenize_varname(const char *varname,
    - ASCII charset,
    - ISO8859-1 charset (aka Latin1),
    - UTF-8 charset (Unicode).
-   See: www.unicode.org/charts & www.czyborra.com/utf
+  See: www.unicode.org/charts & www.czyborra.com/utf
 */
 
 /* TI82 */
@@ -401,50 +393,50 @@ static char transcode_from_ti82_charset_to_latin1(const char c)
     case 0x88: return '8';
     case 0x89: return '9';
 
-    case 0x8a: return (char)192+1;
-    case 0x8b: return (char)192+0;
-    case 0x8c: return (char)192+2;
-    case 0x8d: return (char)192+4;
-    case 0x8e: return (char)224+1;
-    case 0x8f: return (char)224+0;
-    case 0x90: return (char)224+2;
-    case 0x91: return (char)224+4;
-    case 0x92: return (char)200+1;
-    case 0x93: return (char)200+0;
-    case 0x94: return (char)200+2;
-    case 0x95: return (char)200+4;
-    case 0x96: return (char)231+1;
-    case 0x97: return (char)231+0;
-    case 0x98: return (char)231+2;
-    case 0x99: return (char)231+4;
-    case 0x9a: return (char)204+1;
-    case 0x9b: return (char)204+0;
-    case 0x9c: return (char)204+2;
-    case 0x9d: return (char)204+3;
-    case 0x9e: return (char)236+1;
-    case 0x9f: return (char)236+0;
-    case 0xa0: return (char)236+2;
-    case 0xa1: return (char)236+3;
-    case 0xa2: return (char)210+1;
-    case 0xa3: return (char)210+0;
-    case 0xa4: return (char)210+2;
-    case 0xa5: return (char)210+4;
-    case 0xa6: return (char)242+1;
-    case 0xa7: return (char)242+0;
-    case 0xa8: return (char)242+2;
-    case 0xa9: return (char)242+4;
-    case 0xaa: return (char)217+1;
-    case 0xab: return (char)217+0;
-    case 0xac: return (char)217+2;
-    case 0xad: return (char)217+3;
-    case 0xae: return (char)249+1;
-    case 0xaf: return (char)249+0;
-    case 0xb0: return (char)249+2;
-    case 0xb1: return (char)249+3;
-    case 0xb2: return (char)199;
-    case 0xb3: return (char)231;
-    case 0xb4: return (char)209;
-    case 0xb5: return (char)241;
+    case 0x8a: return 192+1;
+    case 0x8b: return 192+0;
+    case 0x8c: return 192+2;
+    case 0x8d: return 192+4;
+    case 0x8e: return 224+1;
+    case 0x8f: return 224+0;
+    case 0x90: return 224+2;
+    case 0x91: return 224+4;
+    case 0x92: return 200+1;
+    case 0x93: return 200+0;
+    case 0x94: return 200+2;
+    case 0x95: return 200+4;
+    case 0x96: return 231+1;
+    case 0x97: return 231+0;
+    case 0x98: return 231+2;
+    case 0x99: return 231+4;
+    case 0x9a: return 204+1;
+    case 0x9b: return 204+0;
+    case 0x9c: return 204+2;
+    case 0x9d: return 204+3;
+    case 0x9e: return 236+1;
+    case 0x9f: return 236+0;
+    case 0xa0: return 236+2;
+    case 0xa1: return 236+3;
+    case 0xa2: return 210+1;
+    case 0xa3: return 210+0;
+    case 0xa4: return 210+2;
+    case 0xa5: return 210+4;
+    case 0xa6: return 242+1;
+    case 0xa7: return 242+0;
+    case 0xa8: return 242+2;
+    case 0xa9: return 242+4;
+    case 0xaa: return 217+1;
+    case 0xab: return 217+0;
+    case 0xac: return 217+2;
+    case 0xad: return 217+3;
+    case 0xae: return 249+1;
+    case 0xaf: return 249+0;
+    case 0xb0: return 249+2;
+    case 0xb1: return 249+3;
+    case 0xb2: return 199;
+    case 0xb3: return 231;
+    case 0xb4: return 209;
+    case 0xb5: return 241;
 
     case 0xd8: return 'n'; // eta, u, v, w: diff between 82 and 83
     default:
@@ -538,50 +530,50 @@ static char transcode_from_ti83_charset_to_latin1(const char c)
     case 0x88: return '8';
     case 0x89: return '9';
 
-    case 0x8a: return (char)192+1;
-    case 0x8b: return (char)192+0;
-    case 0x8c: return (char)192+2;
-    case 0x8d: return (char)192+4;
-    case 0x8e: return (char)224+1;
-    case 0x8f: return (char)224+0;
-    case 0x90: return (char)224+2;
-    case 0x91: return (char)224+4;
-    case 0x92: return (char)200+1;
-    case 0x93: return (char)200+0;
-    case 0x94: return (char)200+2;
-    case 0x95: return (char)200+4;
-    case 0x96: return (char)231+1;
-    case 0x97: return (char)231+0;
-    case 0x98: return (char)231+2;
-    case 0x99: return (char)231+4;
-    case 0x9a: return (char)204+1;
-    case 0x9b: return (char)204+0;
-    case 0x9c: return (char)204+2;
-    case 0x9d: return (char)204+3;
-    case 0x9e: return (char)236+1;
-    case 0x9f: return (char)236+0;
-    case 0xa0: return (char)236+2;
-    case 0xa1: return (char)236+3;
-    case 0xa2: return (char)210+1;
-    case 0xa3: return (char)210+0;
-    case 0xa4: return (char)210+2;
-    case 0xa5: return (char)210+4;
-    case 0xa6: return (char)242+1;
-    case 0xa7: return (char)242+0;
-    case 0xa8: return (char)242+2;
-    case 0xa9: return (char)242+4;
-    case 0xaa: return (char)217+1;
-    case 0xab: return (char)217+0;
-    case 0xac: return (char)217+2;
-    case 0xad: return (char)217+3;
-    case 0xae: return (char)249+1;
-    case 0xaf: return (char)249+0;
-    case 0xb0: return (char)249+2;
-    case 0xb1: return (char)249+3;
-    case 0xb2: return (char)199;
-    case 0xb3: return (char)231;
-    case 0xb4: return (char)209;
-    case 0xb5: return (char)241;
+    case 0x8a: return 192+1;
+    case 0x8b: return 192+0;
+    case 0x8c: return 192+2;
+    case 0x8d: return 192+4;
+    case 0x8e: return 224+1;
+    case 0x8f: return 224+0;
+    case 0x90: return 224+2;
+    case 0x91: return 224+4;
+    case 0x92: return 200+1;
+    case 0x93: return 200+0;
+    case 0x94: return 200+2;
+    case 0x95: return 200+4;
+    case 0x96: return 231+1;
+    case 0x97: return 231+0;
+    case 0x98: return 231+2;
+    case 0x99: return 231+4;
+    case 0x9a: return 204+1;
+    case 0x9b: return 204+0;
+    case 0x9c: return 204+2;
+    case 0x9d: return 204+3;
+    case 0x9e: return 236+1;
+    case 0x9f: return 236+0;
+    case 0xa0: return 236+2;
+    case 0xa1: return 236+3;
+    case 0xa2: return 210+1;
+    case 0xa3: return 210+0;
+    case 0xa4: return 210+2;
+    case 0xa5: return 210+4;
+    case 0xa6: return 242+1;
+    case 0xa7: return 242+0;
+    case 0xa8: return 242+2;
+    case 0xa9: return 242+4;
+    case 0xaa: return 217+1;
+    case 0xab: return 217+0;
+    case 0xac: return 217+2;
+    case 0xad: return 217+3;
+    case 0xae: return 249+1;
+    case 0xaf: return 249+0;
+    case 0xb0: return 249+2;
+    case 0xb1: return 249+3;
+    case 0xb2: return 199;
+    case 0xb3: return 231;
+    case 0xb4: return 209;
+    case 0xb5: return 241;
 
     default:
       return (((uint8_t)c >= 0x20) && ((uint8_t)c < 0x80)) ? c : '_';
@@ -664,50 +656,50 @@ static char transcode_from_ti85_charset_to_latin1(const char c)
     case 0x88: return '8';
     case 0x89: return '9';
 
-    case 0x8a: return (char)192+1;
-    case 0x8b: return (char)192+0;
-    case 0x8c: return (char)192+2;
-    case 0x8d: return (char)192+4;
-    case 0x8e: return (char)224+1;
-    case 0x8f: return (char)224+0;
-    case 0x90: return (char)224+2;
-    case 0x91: return (char)224+4;
-    case 0x92: return (char)200+1;
-    case 0x93: return (char)200+0;
-    case 0x94: return (char)200+2;
-    case 0x95: return (char)200+4;
-    case 0x96: return (char)231+1;
-    case 0x97: return (char)231+0;
-    case 0x98: return (char)231+2;
-    case 0x99: return (char)231+4;
-    case 0x9a: return (char)204+1;
-    case 0x9b: return (char)204+0;
-    case 0x9c: return (char)204+2;
-    case 0x9d: return (char)204+3;
-    case 0x9e: return (char)236+1;
-    case 0x9f: return (char)236+0;
-    case 0xa0: return (char)236+2;
-    case 0xa1: return (char)236+3;
-    case 0xa2: return (char)210+1;
-    case 0xa3: return (char)210+0;
-    case 0xa4: return (char)210+2;
-    case 0xa5: return (char)210+4;
-    case 0xa6: return (char)242+1;
-    case 0xa7: return (char)242+0;
-    case 0xa8: return (char)242+2;
-    case 0xa9: return (char)242+4;
-    case 0xaa: return (char)217+1;
-    case 0xab: return (char)217+0;
-    case 0xac: return (char)217+2;
-    case 0xad: return (char)217+3;
-    case 0xae: return (char)249+1;
-    case 0xaf: return (char)249+0;
-    case 0xb0: return (char)249+2;
-    case 0xb1: return (char)249+3;
-    case 0xb2: return (char)199;
-    case 0xb3: return (char)231;
-    case 0xb4: return (char)209;
-    case 0xb5: return (char)241;
+    case 0x8a: return 192+1;
+    case 0x8b: return 192+0;
+    case 0x8c: return 192+2;
+    case 0x8d: return 192+4;
+    case 0x8e: return 224+1;
+    case 0x8f: return 224+0;
+    case 0x90: return 224+2;
+    case 0x91: return 224+4;
+    case 0x92: return 200+1;
+    case 0x93: return 200+0;
+    case 0x94: return 200+2;
+    case 0x95: return 200+4;
+    case 0x96: return 231+1;
+    case 0x97: return 231+0;
+    case 0x98: return 231+2;
+    case 0x99: return 231+4;
+    case 0x9a: return 204+1;
+    case 0x9b: return 204+0;
+    case 0x9c: return 204+2;
+    case 0x9d: return 204+3;
+    case 0x9e: return 236+1;
+    case 0x9f: return 236+0;
+    case 0xa0: return 236+2;
+    case 0xa1: return 236+3;
+    case 0xa2: return 210+1;
+    case 0xa3: return 210+0;
+    case 0xa4: return 210+2;
+    case 0xa5: return 210+4;
+    case 0xa6: return 242+1;
+    case 0xa7: return 242+0;
+    case 0xa8: return 242+2;
+    case 0xa9: return 242+4;
+    case 0xaa: return 217+1;
+    case 0xab: return 217+0;
+    case 0xac: return 217+2;
+    case 0xad: return 217+3;
+    case 0xae: return 249+1;
+    case 0xaf: return 249+0;
+    case 0xb0: return 249+2;
+    case 0xb1: return 249+3;
+    case 0xb2: return 199;
+    case 0xb3: return 231;
+    case 0xb4: return 209;
+    case 0xb5: return 241;
 
     case 0xd8: return 'n'; // eta, u, v, w: diff between 82 and 83
     default:
@@ -832,32 +824,23 @@ TIEXPORT char* TICALL tifiles_transcode_to_ascii(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: 
-	case CALC_TI84P: 
-		f = transcode_from_ti83_charset_to_ascii; 
+    case CALC_TI83P: f = transcode_from_ti83_charset_to_ascii; 
       break;
-    case CALC_TI82:  
-		f = transcode_from_ti82_charset_to_ascii; 
+    case CALC_TI82:  f = transcode_from_ti82_charset_to_ascii; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  
-		f = transcode_from_ti85_charset_to_ascii; 
+    case CALC_TI86:  f = transcode_from_ti85_charset_to_ascii; 
       break;
     case CALC_TI89:
-    case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  
-		f = transcode_from_ti9x_charset_to_ascii; 
+    case CALC_V200:  f = transcode_from_ti9x_charset_to_ascii; 
       break;
-	default:
-		printl3(2, _("libtifiles error: unknown calc type. Program halted before crashing !\n"));
-		exit(-1);
     }
 
   while(*src)
-    *dest++ = f(*src++);
-  *dest = '\0';
+    *dst++ = f(*src++);
+  *dst = '\0';
 
   return dest;
 }
@@ -875,28 +858,18 @@ TIEXPORT char* TICALL tifiles_transcode_to_latin1(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: 
-	case CALC_TI84P:
-		f = transcode_from_ti83_charset_to_latin1; 
+    case CALC_TI83P: f = transcode_from_ti83_charset_to_latin1; 
       break;
-    case CALC_TI82:  
-		f = transcode_from_ti82_charset_to_latin1; 
+    case CALC_TI82:  f = transcode_from_ti82_charset_to_latin1; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  
-		f = transcode_from_ti85_charset_to_latin1; 
+    case CALC_TI86:  f = transcode_from_ti85_charset_to_latin1; 
       break;
     case CALC_TI89:
-    case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  
-		f = transcode_from_ti9x_charset_to_latin1; 
+    case CALC_V200:  f = transcode_from_ti9x_charset_to_latin1; 
       break;
-	default:
-	  printl3(2, "libtifiles error: unknown calc type. Program halted before crashing !\n");
-		exit(-1);
-	break;
     }
 
   while(*src)
@@ -921,28 +894,18 @@ TIEXPORT char* TICALL tifiles_transcode_to_utf8(char* dst, const char *src)
     {
     case CALC_TI73:
     case CALC_TI83:
-    case CALC_TI83P: 
-	case CALC_TI84P: 
-		f = transcode_from_ti83_charset_to_utf8; 
+    case CALC_TI83P: f = transcode_from_ti83_charset_to_utf8; 
       break;
-    case CALC_TI82:  
-		f = transcode_from_ti82_charset_to_utf8; 
+    case CALC_TI82:  f = transcode_from_ti82_charset_to_utf8; 
       break;
     case CALC_TI85:  
-    case CALC_TI86:  
-		f = transcode_from_ti85_charset_to_utf8; 
+    case CALC_TI86:  f = transcode_from_ti85_charset_to_utf8; 
       break;
     case CALC_TI89:
-	case CALC_TI89T:
     case CALC_TI92:
     case CALC_TI92P:
-    case CALC_V200:  
-		f = transcode_from_ti9x_charset_to_utf8; 
+    case CALC_V200:  f = transcode_from_ti9x_charset_to_utf8; 
       break;
-	default:
-	  printl3(2, "libtifiles error: unknown calc type. Program halted before crashing !\n");
-		exit(-1);
-	break;
     }
 
   while(*src) {
@@ -950,7 +913,7 @@ TIEXPORT char* TICALL tifiles_transcode_to_utf8(char* dst, const char *src)
 
     // write our wide-char
     if ((uint16_t)wchar < 0x80)
-      *dst++ = (char)wchar;
+      *dst++ = wchar;
     else if ((uint16_t)wchar < 0x0800) {
       *dst++ = (0xC0 | (wchar >> 6)) & 0xff;
       *dst++ = (0x80 | (wchar & 0x3f)) & 0xff;
@@ -988,9 +951,9 @@ TIEXPORT TifileEncoding TICALL tifiles_translate_get_encoding(void)
 char *tixx_translate_varname(const char *varname, char *translate,
 			     uint8_t vartype, TicalcType calc_type)
 {
-  char detokenized[18];
+  char detokenized[9];
   char *src = detokenized;
-  char dst[2*18];
+  char dst[17];
 
   tixx_detokenize_varname(varname, detokenized, vartype, calc_type);
 
@@ -1010,14 +973,14 @@ TIEXPORT char *TICALL tifiles_translate_varname(const char *varname,
 						char *translate,
 						uint8_t vartype)
 {
-	return tixx_translate_varname(varname, translate, vartype, 
+  return tixx_translate_varname(varname, translate, vartype, 
 				tifiles_calc_type);
 }
 
 TIEXPORT char *TICALL tifiles_translate_varname_static(const char *varname,
 						       uint8_t vartype)
 {
-  static char trans[18];
+  static char trans[17];
   
   return tifiles_translate_varname(varname, trans, vartype);
 }
