@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: types89.c 784 2004-09-18 17:31:54Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +22,10 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "gettext.h"
+#include "intl.h"
 
 #include "export.h"
 #include "types89.h"
-#include "printl.h"
 
 #ifdef __WIN32__
 # define strcasecmp _stricmp
@@ -73,7 +69,7 @@ const char *TI89_CONST[TI89_MAXTYPES + 1][4] = {
   {"", "89?", "Unknown", N_("Unknown")},
   {"RDIR", "89?", "Unknown", N_("Unknown")},
   {"LDIR", "89?", "Unknown", N_("Unknown")},
-  {"STDY", "89y", "Zipped", N_("Zipped")},
+  {"ZIP", "89y", "Zipped", N_("Zipped")},
   {"BKUP", "89g", "Backup", N_("Backup")},
   {"", "89?", "Unknown", N_("Unknown")},
   {"DIR", "89?", "Unknown", N_("Unknown")},
@@ -114,7 +110,9 @@ uint8_t ti89_type2byte(const char *s)
   }
 
   if (i == TI89_MAXTYPES)
-    printl3(1, _("unknown type. It is a bug. Please report this information.\n"));
+    printf
+	(_
+	 ("Warning: unknown type. It is a bug. Please report this information.\n"));
 
   return i;
 }
@@ -136,7 +134,9 @@ uint8_t ti89_fext2byte(const char *s)
   }
 
   if (i == TI89_MAXTYPES)
-    printl3(1, _("unknown type. It is a bug. Please report this information.\n"));
+    printf
+	(_
+	 ("Warning: unknown type. It is a bug. Please report this information.\n"));
 
   return i;
 }
