@@ -1,8 +1,5 @@
-/* Hey EMACS -*- linux-c -*- */
-/* $Id: types92.c 667 2004-05-03 11:45:01Z tijl $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,11 +22,10 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "gettext.h"
+#include "intl.h"
 
 #include "export.h"
 #include "types92.h"
-#include "printl.h"
 
 #ifdef __WIN32__
 # define strcasecmp _stricmp
@@ -114,7 +110,9 @@ uint8_t ti92_type2byte(const char *s)
   }
 
   if (i == TI92_MAXTYPES)
-    printl3(1, _("unknown type. It is a bug. Please report this information.\n"));
+    fprintf(stdout,
+	    _
+	    ("Warning: unknown type. It is a bug. Please report this information.\n"));
 
   return i;
 }
@@ -136,7 +134,9 @@ uint8_t ti92_fext2byte(const char *s)
   }
 
   if (i == TI92_MAXTYPES)
-    printl3(1, _("unknown type. It is a bug. Please report this information.\n"));
+    fprintf(stdout,
+	    _
+	    ("Warning: unknown type. It is a bug. Please report this information.\n"));
 
   return i;
 }
