@@ -1,8 +1,6 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: typesxx.c 1396 2005-07-20 09:51:58Z roms $ */
-
-/*  libtifiles - Ti File Format library, a part of the TiLP project
- *  Copyright (C) 1999-2004  Romain Lievin
+/*  libtifiles - TI File Format library
+ *  Copyright (C) 2002-2003  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,14 +21,13 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
-#include "gettext.h"
+#include "intl.h"
 
 #include "file_int.h"
 #include "file_def.h"
 #include "file_err.h"
 #include "typesxx.h"
 #include "misc.h"
-#include "printl.h"
 
 extern int tifiles_calc_type;
 
@@ -90,7 +87,6 @@ TIEXPORT const char *TICALL tifiles_vartype2string(uint8_t data)
     return ti83_byte2type(data);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2type(data);
     break;
   case CALC_TI85:
@@ -100,7 +96,6 @@ TIEXPORT const char *TICALL tifiles_vartype2string(uint8_t data)
     return ti86_byte2type(data);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2type(data);
     break;
   case CALC_TI92:
@@ -133,7 +128,6 @@ TIEXPORT uint8_t TICALL tifiles_string2vartype(const char *s)
     return ti83_type2byte(s);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_type2byte(s);
     break;
   case CALC_TI85:
@@ -143,7 +137,6 @@ TIEXPORT uint8_t TICALL tifiles_string2vartype(const char *s)
     return ti86_type2byte(s);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_type2byte(s);
     break;
   case CALC_TI92:
@@ -175,7 +168,6 @@ TIEXPORT const char *TICALL tifiles_vartype2file(uint8_t data)
     return ti83_byte2fext(data);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2fext(data);
     break;
   case CALC_TI85:
@@ -185,7 +177,6 @@ TIEXPORT const char *TICALL tifiles_vartype2file(uint8_t data)
     return ti86_byte2fext(data);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2fext(data);
     break;
   case CALC_TI92:
@@ -217,7 +208,6 @@ TIEXPORT uint8_t TICALL tifiles_file2vartype(const char *s)
     return ti83_fext2byte(s);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_fext2byte(s);
     break;
   case CALC_TI85:
@@ -227,7 +217,6 @@ TIEXPORT uint8_t TICALL tifiles_file2vartype(const char *s)
     return ti86_fext2byte(s);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_fext2byte(s);
     break;
   case CALC_TI92:
@@ -259,7 +248,6 @@ TIEXPORT const char *TICALL tifiles_vartype2desc(uint8_t d)
     return ti83_byte2desc(d);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2desc(d);
     break;
   case CALC_TI85:
@@ -269,7 +257,6 @@ TIEXPORT const char *TICALL tifiles_vartype2desc(uint8_t d)
     return ti86_byte2desc(d);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2desc(d);
     break;
   case CALC_TI92:
@@ -301,7 +288,6 @@ TIEXPORT const char *TICALL tifiles_vartype2icon(uint8_t d)
     return ti83_byte2icon(d);
     break;
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2icon(d);
     break;
   case CALC_TI85:
@@ -311,7 +297,6 @@ TIEXPORT const char *TICALL tifiles_vartype2icon(uint8_t d)
     return ti86_byte2icon(d);
     break;
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2icon(d);
     break;
   case CALC_TI92:
@@ -387,14 +372,12 @@ TIEXPORT const char *TICALL tifiles_group_file_ext()
   case CALC_TI83:
     return "83g";
   case CALC_TI83P:
-  case CALC_TI84P:
     return "8Xg";
   case CALC_TI85:
     return "85g";
   case CALC_TI86:
     return "86g";
   case CALC_TI89:
-  case CALC_TI89T:
     return "89g";
   case CALC_TI92:
     return "92g";
@@ -422,14 +405,12 @@ TIEXPORT const char *TICALL tifiles_backup_file_ext()
   case CALC_TI83:
     return "83b";
   case CALC_TI83P:
-  case CALC_TI84P:
     return "8Xb";
   case CALC_TI85:
     return "85b";
   case CALC_TI86:
     return "86b";
   case CALC_TI89:
-  case CALC_TI89T:
     return "89g";
   case CALC_TI92:
     return "92b";
@@ -457,14 +438,12 @@ TIEXPORT const char *TICALL tifiles_flash_app_file_ext()
   case CALC_TI83:
     return "???";
   case CALC_TI83P:
-  case CALC_TI84P:
     return "8Xk";
   case CALC_TI85:
     return "???";
   case CALC_TI86:
     return "???";
   case CALC_TI89:
-  case CALC_TI89T:
     return "89k";
   case CALC_TI92:
     return "???";
@@ -492,14 +471,12 @@ TIEXPORT const char *TICALL tifiles_flash_os_file_ext()
   case CALC_TI83:
     return "???";
   case CALC_TI83P:
-  case CALC_TI84P:
     return "8Xu";
   case CALC_TI85:
     return "???";
   case CALC_TI86:
     return "???";
   case CALC_TI89:
-  case CALC_TI89T:
     return "89u";
   case CALC_TI92:
     return "???";
@@ -515,7 +492,7 @@ TIEXPORT const char *TICALL tifiles_flash_os_file_ext()
   return NULL;
 }
 
-TIEXPORT int TICALL tifiles_folder_type()
+TIEXPORT const int TICALL tifiles_folder_type()
 {
   switch (tifiles_calc_type) {
   case CALC_NONE:
@@ -527,14 +504,12 @@ TIEXPORT int TICALL tifiles_folder_type()
   case CALC_TI83:
     return TI83_DIR;
   case CALC_TI83P:
-  case CALC_TI84P:
     return TI83p_DIR;
   case CALC_TI85:
     return -1;
   case CALC_TI86:
     return TI86_DIR;
   case CALC_TI89:
-  case CALC_TI89T:
     return TI89_DIR;
   case CALC_TI92:
     return TI92_DIR;
@@ -550,7 +525,7 @@ TIEXPORT int TICALL tifiles_folder_type()
   return -1;
 }
 
-TIEXPORT int TICALL tifiles_flash_type()
+TIEXPORT const int TICALL tifiles_flash_type()
 {
   switch (tifiles_calc_type) {
   case CALC_NONE:
@@ -562,14 +537,12 @@ TIEXPORT int TICALL tifiles_flash_type()
   case CALC_TI83:
     return -1;
   case CALC_TI83P:
-  case CALC_TI84P:
     return TI83p_APPL;
   case CALC_TI85:
     return -1;
   case CALC_TI86:
     return -1;
   case CALC_TI89:
-  case CALC_TI89T:
     return TI89_APPL;
   case CALC_TI92:
     return -1;
@@ -585,7 +558,7 @@ TIEXPORT int TICALL tifiles_flash_type()
   return -1;
 }
 
-TIEXPORT int TICALL tifiles_idlist_type()
+TIEXPORT const int TICALL tifiles_idlist_type()
 {
   switch (tifiles_calc_type) {
   case CALC_NONE:
@@ -597,14 +570,12 @@ TIEXPORT int TICALL tifiles_idlist_type()
   case CALC_TI83:
     return -1;
   case CALC_TI83P:
-  case CALC_TI84P:
     return TI83p_IDLIST;
   case CALC_TI85:
     return -1;
   case CALC_TI86:
     return -1;
   case CALC_TI89:
-  case CALC_TI89T:
     return TI89_IDLIST;
   case CALC_TI92:
     return -1;
@@ -639,16 +610,12 @@ TIEXPORT const char *TICALL tifiles_calc_type_to_string()
     return "92+";
   case CALC_TI92:
     return "92";
-  case CALC_TI89T:
-	  return "89t";
   case CALC_TI89:
     return "89";
   case CALC_TI86:
     return "86";
   case CALC_TI85:
     return "85";
-  case CALC_TI84P:
-    return "84+";
   case CALC_TI83P:
     return "83+";
   case CALC_TI83:
@@ -688,14 +655,12 @@ TIEXPORT const char *TICALL tifiles_calctype2signature(TicalcType
   case CALC_TI83:
     return "**TI83**";
   case CALC_TI83P:
-  case CALC_TI84P:
     return "**TI83F*";
   case CALC_TI85:
     return "**TI85**";
   case CALC_TI86:
     return "**TI86**";
   case CALC_TI89:
-  case CALC_TI89T:
     return "**TI89**";
   case CALC_TI92:
     return "**TI92**";
@@ -743,8 +708,6 @@ TIEXPORT TicalcType TICALL tifiles_signature2calctype(const char *s)
 /* Query functions */
 /*******************/
 
-#define TIB_SIGNATURE	"Advanced Mathematics Software"
-
 /*
   Check if the file is a valid TI file by
   reading its signature
@@ -755,8 +718,6 @@ TIEXPORT int TICALL tifiles_is_a_ti_file(const char *filename)
 {
   FILE *f;
   char buf[9];
-  char str[64];
-  char *p;
 
   // bug: check the file is not an fifo
   if (!is_regfile(filename))
@@ -764,18 +725,11 @@ TIEXPORT int TICALL tifiles_is_a_ti_file(const char *filename)
 
   f = fopen(filename, "rb");
   if (f == NULL) {
-    //printl3(2, "unable to open this file: <%s>\n", filename);
+    printf("Unable to open this file: <%s>\n", filename);
     return ERR_FILE_OPEN;
   }
-
-  // read header
   fread_8_chars(f, buf);
-#if 0
-  strupr(buf);
-#else
-  for(p = buf; *p != '\0'; p++)
-      *p = toupper(*p);
-#endif
+
   if (!strcmp(buf, "**TI73**") || !strcmp(buf, "**TI82**") ||
       !strcmp(buf, "**TI83**") || !strcmp(buf, "**TI83F*") ||
       !strcmp(buf, "**TI85**") || !strcmp(buf, "**TI86**") ||
@@ -786,15 +740,6 @@ TIEXPORT int TICALL tifiles_is_a_ti_file(const char *filename)
     return !0;
   }
 
-  // check for TIB file
-  fread_n_chars(f, 14, str);
-  fread_n_chars(f, strlen(TIB_SIGNATURE), str);
-  str[strlen(TIB_SIGNATURE)] = '\0';
-  if(!strcmp(str, TIB_SIGNATURE)) {
-	fclose(f);
-	return !0;
-  }
-
   fclose(f);
   return 0;
 }
@@ -827,9 +772,6 @@ TIEXPORT int TICALL tifiles_is_a_group_file(const char *filename)
   int i;
   char *e = tifiles_get_extension(filename);
 
-  if (e == NULL)
-    return 0;
-
   if (!tifiles_is_a_ti_file(filename))
     return 0;
 
@@ -865,9 +807,6 @@ TIEXPORT int TICALL tifiles_is_a_backup_file(const char *filename)
   int i;
   char *e = tifiles_get_extension(filename);
 
-  if (e == NULL)
-    return 0;
-
   if (!tifiles_is_a_ti_file(filename))
     return 0;
 
@@ -889,45 +828,18 @@ TIEXPORT int TICALL tifiles_is_a_flash_file(const char *filename)
   int i;
   char *e = tifiles_get_extension(filename);
 
-  if (e == NULL)
-    return 0;
-
   if (!tifiles_is_a_ti_file(filename))
     return 0;
 
   for (i = 1; i < NCALCS + 1; i++) {
     if ((!strcasecmp(e, FLASH_APP_FILE_EXT[i])) ||
-	(!strcasecmp(e, FLASH_OS_FILE_EXT[i])))
+	(!strcasecmp(e, FLASH_OS_FILE_EXT[i])) || (!strcasecmp(e, "tib")))
       return !0;
   }
 
   return 0;
 }
 
-/* 
-   Check whether it is a tib file
-   - filename [in]: a file name
-   - int [out]: TRUE if tib file, FALSE otherwise
-*/
-TIEXPORT int TICALL tifiles_is_a_tib_file(const char *filename)
-{
-	char *e = tifiles_get_extension(filename);
-
-	if (e == NULL)
-	  return 0;
-
-	if (!tifiles_is_a_ti_file(filename))
-		return 0;
-
-	if(!strcasecmp(e, "tib"))
-		return !0;
-
-	// no need to do more test, TIB signature has already been checked 
-	// by is_a_ti_file()
-
-	return 0;
-}
-
 /* Note: a better way should be to open the file and read the signature */
 /* 
    Return the calc type corresponding to the file
@@ -968,7 +880,7 @@ TIEXPORT int TICALL tifiles_which_calc_type(const char *filename)
   else
     type = CALC_NONE;
 
-  free(ext); // fault under Win32 ?!
+  //free(ext); // fault under Win32 ?!
 
   return type;
 }
@@ -1015,7 +927,6 @@ TIEXPORT const char *TICALL tifiles_file_descriptive(const char *filename)
   if (tifiles_is_a_group_file(filename)) {
     switch (tifiles_which_calc_type(filename)) {
     case CALC_TI89:
-	case CALC_TI89T:
     case CALC_TI92P:
     case CALC_V200:
       return _("Group/Backup");
@@ -1032,14 +943,12 @@ TIEXPORT const char *TICALL tifiles_file_descriptive(const char *filename)
   case CALC_TI83:
     return ti83_byte2desc(ti83_fext2byte(ext));
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2desc(ti83p_fext2byte(ext));
   case CALC_TI85:
     return ti85_byte2desc(ti85_fext2byte(ext));
   case CALC_TI86:
     return ti86_byte2desc(ti86_fext2byte(ext));
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2desc(ti89_fext2byte(ext));
   case CALC_TI92:
     return ti92_byte2desc(ti92_fext2byte(ext));
@@ -1080,7 +989,6 @@ TIEXPORT const char *TICALL tifiles_file_icon(const char *filename)
   if (tifiles_is_a_group_file(filename)) {
     switch (tifiles_which_calc_type(filename)) {
     case CALC_TI89:
-	case CALC_TI89T:
     case CALC_TI92P:
     case CALC_V200:
       return "Group/Backup";
@@ -1097,14 +1005,12 @@ TIEXPORT const char *TICALL tifiles_file_icon(const char *filename)
   case CALC_TI83:
     return ti83_byte2icon(ti83_fext2byte(ext));
   case CALC_TI83P:
-  case CALC_TI84P:
     return ti83p_byte2icon(ti83p_fext2byte(ext));
   case CALC_TI85:
     return ti85_byte2icon(ti85_fext2byte(ext));
   case CALC_TI86:
     return ti86_byte2icon(ti86_fext2byte(ext));
   case CALC_TI89:
-  case CALC_TI89T:
     return ti89_byte2icon(ti89_fext2byte(ext));
   case CALC_TI92:
     return ti92_byte2icon(ti92_fext2byte(ext));
@@ -1128,8 +1034,8 @@ TIEXPORT int TICALL tifiles_is_ti8x(TicalcType calc_type)
 {
   return ((calc_type == CALC_TI73) || (calc_type == CALC_TI82) ||
 	  (calc_type == CALC_TI82) || (calc_type == CALC_TI83) ||
-	  (calc_type == CALC_TI83P) || (calc_type == CALC_TI84P) ||
-	  (calc_type == CALC_TI85) || (calc_type == CALC_TI86));
+	  (calc_type == CALC_TI83P) || (calc_type == CALC_TI85) ||
+	  (calc_type == CALC_TI86));
 }
 
 /*
@@ -1137,8 +1043,7 @@ TIEXPORT int TICALL tifiles_is_ti8x(TicalcType calc_type)
 */
 TIEXPORT int TICALL tifiles_is_ti9x(TicalcType calc_type)
 {
-  return ((calc_type == CALC_TI89) || (calc_type == CALC_TI89T) ||
-	  (calc_type == CALC_TI92) ||
+  return ((calc_type == CALC_TI89) || (calc_type == CALC_TI92) ||
 	  (calc_type == CALC_TI92P) || (calc_type == CALC_V200));
 }
 
@@ -1156,9 +1061,8 @@ TIEXPORT int TICALL tifiles_is_silent(TicalcType calc_type)
 */
 TIEXPORT int TICALL tifiles_has_folder(TicalcType calc_type)
 {
-  return ((calc_type == CALC_TI89) || (calc_type == CALC_TI89T) ||
-	  (calc_type == CALC_TI92) || (calc_type == CALC_TI92P) || 
-	  (calc_type == CALC_V200));
+  return ((calc_type == CALC_TI89) || (calc_type == CALC_TI92) ||
+	  (calc_type == CALC_TI92P) || (calc_type == CALC_V200));
 }
 
 /*
@@ -1167,7 +1071,6 @@ TIEXPORT int TICALL tifiles_has_folder(TicalcType calc_type)
 TIEXPORT int TICALL tifiles_is_flash(TicalcType calc_type)
 {
   return ((calc_type == CALC_TI73) || (calc_type == CALC_TI83P) ||
-	  (calc_type == CALC_TI84P) || (calc_type == CALC_TI89T) ||
 	  (calc_type == CALC_TI89) || (calc_type == CALC_TI92P) ||
 	  (calc_type == CALC_V200));
 }
